experimental_lowqa.tasks package — docs

Skip to main content
`Ctrl`+`K`

# experimental_lowqa.tasks package

## Subpackages

- experimental_lowqa.tasks.yambs package
  - Subpackages
    - experimental_lowqa.tasks.yambs.jlink package
      - Submodules
      - experimental_lowqa.tasks.yambs.jlink.gdbserver module
      - Module contents
  - Submodules
  - experimental_lowqa.tasks.yambs.common module
    - `add_path()`
    - `add_program_path()`
    - `is_local_bin()`
    - `lbin()`
    - `link_local_bin()`
    - `program_str()`
  - experimental_lowqa.tasks.yambs.gcov module
    - `gcov_data()`
    - `remove_gcov_data()`
  - experimental_lowqa.tasks.yambs.udev module
    - `install_udev_rule()`
  - Module contents

## Submodules

## experimental_lowqa.tasks.conntextual module

A module capable of registering workflow tasks for invoking project-specific conntextual tasks.

class experimental_lowqa.tasks.conntextual.ConntextualTask(name: str, *args, execute: Callable[[dict[str, dict[str, Any]], dict[str, Any]], Coroutine[Any, Any, bool]] = None, log: Logger = None, timer: Timer = None, target: Target = None, **kwargs)

  Bases: `SubprocessLogMixin`

  A task for running conntextual.

  default_requirements: set[str] = {'python-install-conntextual', 'venv', 'vmklib.init'}
  async run(inbox: dict[str, dict[str, Any]], outbox: dict[str, Any], *args, **kwargs) → bool

    Generate ninja configuration files.

experimental_lowqa.tasks.conntextual.register(manager: TaskManager, project: str, cwd: Path, substitutions: Dict[str, str], prefix: str = 'r') → bool

  Register project tasks to the manager.

## experimental_lowqa.tasks.docs module

A module for project documentation tasks.

class experimental_lowqa.tasks.docs.SphinxTask(name: str, *args, execute: Callable[[dict[str, dict[str, Any]], dict[str, Any]], Coroutine[Any, Any, bool]] = None, log: Logger = None, timer: Timer = None, target: Target = None, **kwargs)

  Bases: `SubprocessLogMixin`

  A class to facilitate generating documentation with sphinx.

  default_requirements: set[str] = {'python-editable', 'python-install-sphinx', 'python-install-sphinx-book-theme', 'venv'}
  async run(inbox: dict[str, dict[str, Any]], outbox: dict[str, Any], *args, **kwargs) → bool

    Generate ninja configuration files.

## experimental_lowqa.tasks.python module

A module for Python-project task registration.

class experimental_lowqa.tasks.python.PythonTags(name: str, *args, execute: Callable[[dict[str, dict[str, Any]], dict[str, Any]], Coroutine[Any, Any, bool]] = None, log: Logger = None, timer: Timer = None, target: Target = None, **kwargs)

  Bases: `GenerateTags`

  A class implementing a task for generating tags files.

  extra_source_candidates: list[tuple[str | Path, ...]] = [('tasks',), ('tests',), (PosixPath('/home/runner'), 'src', 'python', 'cpython', 'Lib')]
  languages = 'Python'
  async run(inbox: dict[str, dict[str, Any]], outbox: dict[str, Any], *args, **kwargs) → bool

    Generate a tags files.

experimental_lowqa.tasks.python.to_slug(data: str) → str

  Get a slug from a string.

## experimental_lowqa.tasks.runtimepy module

A module for tasks related to the runtimepy project.

class experimental_lowqa.tasks.runtimepy.ArbiterTask(name: str, *args, execute: Callable[[dict[str, dict[str, Any]], dict[str, Any]], Coroutine[Any, Any, bool]] = None, log: Logger = None, timer: Timer = None, target: Target = None, **kwargs)

  Bases: `SubprocessLogMixin`

  A task for running the runtime arbiter.

  default_requirements: set[str] = {'python-editable', 'venv', 'vmklib.init'}
  async run(inbox: dict[str, dict[str, Any]], outbox: dict[str, Any], *args, **kwargs) → bool

    Generate ninja configuration files.

## Module contents